@@ -1,5 +1,5 @@
 // blassic.cpp
-// Revision 7-feb-2005
+// Revision 24-apr-2009
 
 #include "blassic.h"
 
@@ -23,9 +23,12 @@
 #include <fstream>
 //#include <iomanip>
 #include <sstream>
-#include <signal.h>
 #include <memory>
+
 #include <stdio.h>
+#include <string.h>
+#include <signal.h>
+
 
 #ifdef BLASSIC_USE_WINDOWS
 
@@ -312,6 +315,7 @@ private:
 	bool handle_option_info (int & n);
 	bool handle_option_cpc (int & n);
 	bool handle_option_spectrum (int & n);
+	bool handle_option_msx (int & n);
 	bool handle_option_gwbasic (int & n);
 	bool handle_option_appleII (int & n);
 	bool handle_option_allflags (int & n);
@@ -377,6 +381,7 @@ bool Options::initmapoption ()
 	mapoption ["--info"]= & Options::handle_option_info;
 	mapoption ["--cpc"]= & Options::handle_option_cpc;
 	mapoption ["--spectrum"]= & Options::handle_option_spectrum;
+	mapoption ["--msx"]= & Options::handle_option_msx;
 	mapoption ["--gwbasic"]= & Options::handle_option_gwbasic;
 	mapoption ["--appleII"]= & Options::handle_option_appleII;
 	mapoption ["--allflags"]= & Options::handle_option_allflags;
@@ -551,6 +556,19 @@ bool Options::handle_option_spectrum (int & /* n */)
 	return false;
 }
 
+bool Options::handle_option_msx (int & /* n */)
+{
+	TRACEFUNC (tr, "handle_option_msx");
+
+	sysvar::setFlags1 (sysvar::ThenOmitted |
+		sysvar::SpaceBefore | sysvar::SpaceStr_s);
+	sysvar::set16 (sysvar::Zone, 14);
+
+	charset::default_charset= & charset::msx_data;
+
+	return false;
+}
+
 bool Options::handle_option_gwbasic (int & /* n */)
 {
 	TRACEFUNC (tr, "handle_option_gwbasic");
