@@ -2,7 +2,7 @@
 #define INCLUDE_BLASSIC_CHARSET_H
 
 // charset.h
-// Revision 28-jul-2004
+// Revision 13-jun-2006
 
 namespace charset {
 
@@ -12,6 +12,7 @@ typedef chardata chardataset [256];
 extern const chardataset default_data;
 extern const chardataset cpc_data;
 extern const chardataset spectrum_data;
+extern const chardataset msx_data;
 
 extern chardataset data;
 
