@@ -1,5 +1,5 @@
 // cursor.cpp
-// Revision 7-feb-2005
+// Revision 24-apr-2009
 
 #include "cursor.h"
 
@@ -20,6 +20,7 @@ using std::endl;
 #include <queue>
 #include <sstream>
 
+#include <string.h>
 
 #ifdef BLASSIC_USE_WINDOWS
 
