@@ -1,5 +1,5 @@
 // program.cpp
-// Revision 8-feb-2005
+// Revision 24-apr-2009
 
 #include "program.h"
 
@@ -27,6 +27,8 @@ using std::flush;
 #include <cassert>
 #define ASSERT assert
 
+#include <string.h>
+
 #ifndef USE_HASH_MAP
 
 #include <map>
